ReadBufCursor

Struct ReadBufCursor 

pub struct ReadBufCursor<'a> { /* private fields */ }
Cursor over the unfilled portion of a read buffer.

This provides methods to advance and modify the unfilled portion of the buffer.

Implementations

Source

impl ReadBufCursor<'_>

pub unsafe fn as_mut(&mut self) -> &mut Vec<u8>

Returns a mutable reference to the underlying buffer.

Safety

The caller must ensure that the buffer is properly initialized.

pub fn filled(&self) -> &[u8]

Returns the filled portion of the buffer.

pub unsafe fn advance(&mut self, n: usize)

Advances the cursor by n bytes.

Safety

The caller must ensure that n bytes have been initialized in the buffer.

Panics

Panics if advancing by n would cause an overflow.

pub fn remaining(&self) -> usize

Returns the remaining capacity in the buffer.

pub fn put_slice(&mut self, buf: &[u8])

Copies bytes from the provided buffer into this cursor.

Panics

Panics if the buffer doesn’t have enough remaining capacity.